@@ -34,7 +34,8 @@ class DataSource:
     def __init__(self, dbstream: DBStream, path_to_datasource_folder,
                  schema_prefix=None,
                  layer_type='datasource',
-                 loader_function=None):
+                 loader_function=None,
+                 update_schema_name_with_env=True):
         """
 
         :param dbstream:
@@ -45,6 +46,7 @@ class DataSource:
         self.schema_prefix = schema_prefix
         self.layer_type = layer_type
         self.loader_function = loader_function
+        self.update_schema_name_with_env = update_schema_name_with_env
 
     def _build_folder_path(self, layer_name):
         return self.path_to_datasource_folder + 'layers/' + layer_name + "/"
@@ -129,7 +131,7 @@ class DataSource:
         filled_query = query_template.substitute(dict_params)
         return filled_query
 
-    def compute(self, layer_name, query_name=None, environment="production"):
+    def compute(self, layer_name, query_name=None, environment="production", comparison_test=True):
         query_list, queries_config, schema_name, folder_path = self._get_query_list(
             layer_name=layer_name,
             query_name=query_name
@@ -137,11 +139,16 @@ class DataSource:
 
         for query in query_list:
             log_info("Layer: %s | Query started: %s | Environment: %s" % (layer_name, query, environment))
+            schema_name_filled_query = schema_name
+            if self.update_schema_name_with_env:
+                schema_name_filled_query = schema_name if environment == 'production' else (
+                        schema_name + "_" + environment
+                )
             filled_query = self._filled_query(
                 queries_config=queries_config,
                 query=query,
                 folder_path=folder_path,
-                schema_name=schema_name if environment == 'production' else (schema_name + "_" + environment),
+                schema_name=schema_name_filled_query,
                 layer_name=layer_name,
                 environment=environment
             )
@@ -181,7 +188,7 @@ class DataSource:
                     table_name=destination_tables_with_schema["production"].split(".")[1],
                 )
 
-        if environment != 'production':
+        if environment != 'production' and comparison_test:
             self.compute_comparison(
                 schema_name=schema_name,
                 tables_list=query_list,
@@ -270,9 +277,9 @@ class DataSource:
             print(tabulate(values, headers=headers, tablefmt="fancy_grid", floatfmt=".2f"))
             print("=============================")
 
-    def function_compute(self, layer_name, environment='production'):
+    def function_compute(self, layer_name, environment='production', comparison_test=True):
         def f():
-            self.compute(layer_name=layer_name, environment=environment)
+            self.compute(layer_name=layer_name, environment=environment, comparison_test=comparison_test)
 
         return f
 
